pub struct RetentionPartial {
pub read: Option<u32>,
pub write: Option<u32>,
pub ddl: Option<u32>,
pub admin: Option<u32>,
pub tx_ctrl: Option<u32>,
}Fields
read: Option<u32>write: Option<u32>ddl: Option<u32>admin: Option<u32>tx_ctrl: Option<u32>Trait Implementations
Sourceimpl Debug for RetentionPartial
impl Debug for RetentionPartial
Sourceimpl Default for RetentionPartial
impl Default for RetentionPartial
Sourceimpl<'de> Deserialize<'de> for RetentionPartial
impl<'de> Deserialize<'de> for RetentionPartial
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RetentionPartial
impl JsonSchema for RetentionPartial
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RetentionPartial
impl RefUnwindSafe for RetentionPartial
impl Send for RetentionPartial
impl Sync for RetentionPartial
impl Unpin for RetentionPartial
impl UnsafeUnpin for RetentionPartial
impl UnwindSafe for RetentionPartial