pub struct TablePolicyParams {
pub connection: Option<String>,
pub table: String,
pub policy: PartialPolicy,
}Fields
connection: Option<String>table: StringTable key: database.table for exact rules or database.* wildcard.
policy: PartialPolicyTrait Implementations
Sourceimpl Debug for TablePolicyParams
impl Debug for TablePolicyParams
Sourceimpl<'de> Deserialize<'de> for TablePolicyParams
impl<'de> Deserialize<'de> for TablePolicyParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TablePolicyParams
impl JsonSchema for TablePolicyParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TablePolicyParams
impl RefUnwindSafe for TablePolicyParams
impl Send for TablePolicyParams
impl Sync for TablePolicyParams
impl Unpin for TablePolicyParams
impl UnsafeUnpin for TablePolicyParams
impl UnwindSafe for TablePolicyParams